==> deepin-repair-tools_1.0.9.orig.tar.xz: deepin-repair-tools-1.0.9/translations/deepin-repair-tools_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>DPKG Onar</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Detayları göster</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Detayları gizle</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Uygulama yüklenemiyor veya yükseltilemiyor</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Onarılıyor, lütfen bekleyiniz...</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Onarım başarısız</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair succeeded</source>
        <translation>Onarım başarılı</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Disk Temizle</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Sistem bölümü</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="152"/>
        <source>%1 (on %2)</source>
        <translation>%1 (%2 &apos;sinde)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="191"/>
        <source>Cleaning %1</source>
        <translation>Temizleniyor %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="237"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 temizlendi</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Önyükleme Onar</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Detayları göster</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Detayları gzle</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Sisteme girmek için önyükleme menüsü bulunamıyor</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Onarılıyor, lütfen bekleyiniz...</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair succeeded</source>
        <translation>Onarım başarılı</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Onarım başarısız</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Parola Sıfırla</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Doğrula</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Parolayı sıfırla</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Parolayı doğrula</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Lütfen yeni bir şifre giriniz</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>The two passwords don&apos;t match</source>
        <translation>İki parola eşleşmiyor</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="128"/>
        <source>Reset password successfully</source>
        <translation>Parola sıfırlama başarılı</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="154"/>
        <source>Forgot login password</source>
        <translation>Unutulan giriş parolası</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="142"/>
        <source>%1 (on %2)</source>
        <translation>%1 (%2 &apos;sinde)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>İzin Onar</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>Ayrıcalık hatası sebebiyle masaüstüne girilemiyor</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="72"/>
        <source>Repairing, please wait...</source>
        <translation>Onarılıyor, lütfen bekleyiniz...</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="91"/>
        <source>Reset privilege successfully</source>
        <translation>İzin sıfırlama başarılı</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="94"/>
        <source>Reset privilege failed</source>
        <translation>İzin sıfırlama başarısız</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Sabit disk durumu kontrol ediliyor, lütfen bekleyiniz...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="36"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="40"/>
        <source>Restart Now</source>
        <translation>Şimdi Yeniden Başlat</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="139"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Sabit disk %1 hatası, lütfen onarınız</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="151"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Onarım işlemini bitirmek için lütfen bilgisayarınızı yeniden başlatınız</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="177"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Sabit disk onarılıyor, lütfen bekleyiniz...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="140"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>Onarım veri kaybına neden olabilir, lütfen onaylayarak ve devam ediniz</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="38"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>Repair succeeded</source>
        <translation>Onarım başarılı</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="156"/>
        <source>Repair failed</source>
        <translation>Onarım başarısız</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="45"/>
        <source>Deepin Repair</source>
        <translation>Deepin Onarım</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="46"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Onarım, kullanıcıların sabit disk algılama, disk temizleme, DPKG onarımı, önyükleme onarımı, ayrıcalık onarımı, parola sıfırlama vb. Dahil olmak üzere Deepin&apos;deki bazı sorunların hızlı bir şekilde düzeltilmesine yardımcı olmak için kullanılan bir araçtır.</translation>
    </message>
</context>
</TS>

==> deepin-repair-tools_1.0.14.orig.tar.xz: deepin-repair-tools-1.0.14/translations/deepin-repair-tools_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>DPKGRepair</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkg_repair_plugin.h" line="21"/>
        <source>DPKG Repair</source>
        <translation>DPKG Onarımı</translation>
    </message>
</context>
<context>
    <name>DPKGRepairWidget</name>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="33"/>
        <source>Show details</source>
        <translation>Ayrıntıları görüntüle</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="34"/>
        <source>Hide details</source>
        <translation>Ayrıntıları gizle</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="39"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="40"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="83"/>
        <source>Cannot install or upgrade application</source>
        <translation>Uygulama kurulamadı ya da yükseltilemedi</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="104"/>
        <source>Repairing, please wait...</source>
        <translation>Onarılıyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="131"/>
        <source>Repair failed</source>
        <translation>Onarılamadı</translation>
    </message>
    <message>
        <location filename="../plugins/dpkg_repair/dpkgrepairwidget.cpp" line="134"/>
        <source>Repair successful</source>
        <translation>Onarıldı</translation>
    </message>
</context>
<context>
    <name>DiskClean</name>
    <message>
        <location filename="../plugins/disk_clean/disk_clean_plugin.h" line="22"/>
        <source>Disk Clean</source>
        <translation>Disk Temizleme</translation>
    </message>
</context>
<context>
    <name>DiskCleanWidget</name>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="62"/>
        <source>System partition</source>
        <translation>Sistem bölümü</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="64"/>
        <source>Clean</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="65"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="67"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="153"/>
        <source>%1 (on %2)</source>
        <translation>%1 (%2 üzerinde)</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="192"/>
        <source>Cleaning %1</source>
        <translation>Temizleniyor %1</translation>
    </message>
    <message>
        <location filename="../plugins/disk_clean/diskcleanwidget.cpp" line="238"/>
        <source>%1 has been cleaned up</source>
        <translation>%1 temizlendi</translation>
    </message>
</context>
<context>
    <name>GrubRepair</name>
    <message>
        <location filename="../plugins/grub_repair/grub_repair_plugin.h" line="21"/>
        <source>Boot Repair</source>
        <translation>Ön Yükleme Onarımı</translation>
    </message>
</context>
<context>
    <name>GrubRepairWidget</name>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="31"/>
        <source>Show details</source>
        <translation>Ayrıntıları görüntüle</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="32"/>
        <source>Hide details</source>
        <translation>Ayrıntıları gizle</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="36"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="37"/>
        <source>Cannot find boot menu to enter system</source>
        <translation>Sisteme girmek için ön yükleme menüsü bulunamadı</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="41"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="93"/>
        <source>Repairing, please wait...</source>
        <translation>Onarılıyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="147"/>
        <source>Repair successful</source>
        <translation>Onarıldı</translation>
    </message>
    <message>
        <location filename="../plugins/grub_repair/grubrepairwidget.cpp" line="150"/>
        <source>Repair failed</source>
        <translation>Onarılamadı</translation>
    </message>
</context>
<context>
    <name>PasswordReset</name>
    <message>
        <location filename="../plugins/password_reset/password_reset_plugin.h" line="21"/>
        <source>Password Reset</source>
        <translation>Parolayı Sıfırla</translation>
    </message>
</context>
<context>
    <name>PasswordResetWidget</name>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="29"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="28"/>
        <source>Reset password</source>
        <translation>Parolayı sıfırla</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="30"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="31"/>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="32"/>
        <source>Confirm password</source>
        <translation>Parola onayı</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="81"/>
        <source>Please enter a new password</source>
        <translation>Lütfen yeni bir parola yazın</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="97"/>
        <source>Passwords do not match</source>
        <translation>Parola ve onayı aynı değil</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="130"/>
        <source>Reset password successfully</source>
        <translation>Parola sıfırlandı</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="156"/>
        <source>Forgot login password</source>
        <translation>Oturum açma parolasını unuttum</translation>
    </message>
    <message>
        <location filename="../plugins/password_reset/passwordresetwidget.cpp" line="144"/>
        <source>%1 (on %2)</source>
        <translation>%1 (%2 üzerinde)</translation>
    </message>
</context>
<context>
    <name>PermissionsRepair</name>
    <message>
        <location filename="../plugins/permissions_repair/permissions_repair_plugin.h" line="21"/>
        <source>Privilege Repair</source>
        <translation>İzin Onarımı</translation>
    </message>
</context>
<context>
    <name>PermissionsRepairWidget</name>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="23"/>
        <source>Cannot enter desktop due to privilege error</source>
        <translation>İzin sorunu nedeniyle masaüstüne girilemiyor</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="26"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="27"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="71"/>
        <source>Repairing, please wait...</source>
        <translation>Onarılıyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="90"/>
        <source>Reset privilege successfully</source>
        <translation>İzin sıfırlandı</translation>
    </message>
    <message>
        <location filename="../plugins/permissions_repair/permissionsrepairwidget.cpp" line="93"/>
        <source>Reset failed</source>
        <translation>Sıfırlanamadı</translation>
    </message>
</context>
<context>
    <name>ScanningPage</name>
    <message>
        <location filename="../src/scanningpage.cpp" line="27"/>
        <source>Checking hard disk status, please wait...</source>
        <translation>Sabit disk durumu denetleniyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="34"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="37"/>
        <source>Repair</source>
        <translation>Onar</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="41"/>
        <source>Restart Now</source>
        <translation>Şimdi Yeniden Başlat</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="149"/>
        <source>Hard disk partition %1 error, please repair</source>
        <translation>Sabit diskin %1. bölümünde sorun var, lütfen onarın</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="160"/>
        <source>Repair successful</source>
        <translation>Onarıldı</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="161"/>
        <source>Please restart your computer to finish repairing</source>
        <translation>Lütfen onarımı tamamlamak için bilgisayarı yeniden başlatın</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="187"/>
        <source>Repairing hard disk, please wait...</source>
        <translation>Sabit disk onarılıyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="150"/>
        <source>The repair may cause data loss, please confirm and continue</source>
        <translation>Bu onarım veri kaybına neden olabilir. Lütfen devam etmek için onaylayın</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="39"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../src/scanningpage.cpp" line="166"/>
        <source>Repair failed</source>
        <translation>Onarılamadı</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Repair</source>
        <translation>Deepin Onarım</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="48"/>
        <source>Deepin Repair is a tool to help users quickly fix some issues in deepin, including hard disk detecting, disk cleaning, DPKG repairing, boot repairing, privilege repairing, password reset, etc.</source>
        <translation>Deepin Onarım, kullanıcıların Deepin üzerindeki sorunları hızlıca düzeltebilmesini ve sabit disk algılama, disk temizleme, DPKG onarımı, ön yükleme onarımı, izin onarımı, parola sıfırlama gibi işlemleri yapmasını sağlayan bir araçtır.</translation>
    </message>
</context>
</TS>
